@@ -1,8 +1,8 @@
-package URI;  # $Date: 2001/02/27 17:35:13 $
+package URI;  # $Date: 2002/09/03 03:35:23 $
 
 use strict;
 use vars qw($VERSION);
-$VERSION = "1.11";
+$VERSION = "1.22";
 
 use vars qw($ABS_REMOTE_LEADING_DOTS $ABS_ALLOW_RELATIVE_SCHEME);
 
@@ -11,7 +11,7 @@ my %implements;  # mapping from scheme to implementor class
 # Some "official" character classes
 
 use vars qw($reserved $mark $unreserved $uric $scheme_re);
-$reserved   = q(;/?:@&=+$,);
+$reserved   = q(;/?:@&=+$,[]);
 $mark       = q(-_.!~*'());                                    #'; emacs
 $unreserved = "A-Za-z0-9\Q$mark\E";
 $uric       = quotemeta($reserved) . $unreserved . "%";
@@ -82,7 +82,7 @@ sub _init
 sub implementor
 {
     my($scheme, $impclass) = @_;
-    unless ($scheme) {
+    if (!$scheme || $scheme !~ /\A$scheme_re\z/o) {
 	require URI::_generic;
 	return "URI::_generic";
     }
@@ -302,7 +302,7 @@ URI - Uniform Resource Identifiers (absolute and relative)
 
 This module implements the C<URI> class.  Objects of this class
 represent "Uniform Resource Identifier references" as specified in RFC
-2396.
+2396 (and updated by RFC 2732).
 
 A Uniform Resource Identifier is a compact string of characters for
 identifying an abstract or physical resource.  A Uniform Resource
@@ -648,8 +648,7 @@ $uri->selector, $uri->search, $uri->string.
 
 =item B<http>:
 
-The I<http> URI scheme is specified in
-<draft-ietf-http-v11-spec-rev-06> (which will become an RFC soon).
+The I<http> URI scheme is specified in RFC 2616.
 The scheme is used to reference resources hosted by HTTP servers.
 
 C<URI> objects belonging to the http scheme support the common,
@@ -659,13 +658,13 @@ generic and server methods.
 
 The I<https> URI scheme is a Netscape invention which is commonly
 implemented.  The scheme is used to reference HTTP servers through SSL
-connections.  It's syntax is the same as http, but the default
+connections.  Its syntax is the same as http, but the default
 port is different.
 
 =item B<ldap>:
 
 The I<ldap> URI scheme is specified in RFC 2255.  LDAP is the
-Lightweight Directory Access Protocol.  A ldap URI describes an LDAP
+Lightweight Directory Access Protocol.  An ldap URI describes an LDAP
 search operation to perform to retrieve information from an LDAP
 directory.
 
@@ -714,6 +713,18 @@ An old specification of the I<rlogin> URI scheme is found in RFC
 1738. C<URI> objects belonging to the rlogin scheme support the
 common, generic and server methods.
 
+=item B<rtsp>:
+
+The I<rtsp> URL specification can be found in section 3.2 of RFC 2326.
+C<URI> objects belonging to the rtsp scheme support the common,
+generic, and server methods, with the exception of userinfo and
+query-related sub-components.
+
+=item B<rtspu>:
+
+The I<rtspu> URI scheme is used to talk to RTSP servers over UDP
+instead of TCP.  The syntax is the same as rtsp.
+
 =item B<rsync>:
 
 Information about rsync is available from http://rsync.samba.org.
@@ -721,9 +732,22 @@ C<URI> objects belonging to the rsync scheme support the common,
 generic and server methods.  In addition they provide methods to
 access the userinfo sub-components: $uri->user and $uri->password.
 
+=item B<sip>:
+
+The I<sip> URI specification is described in sections 19.1 and 25
+of RFC 3261.  C<URI> objects belonging to the sip scheme support the
+common, generic, and server methods with the exception of path related
+sub-components.  In addition, they provide two methods to get and set
+I<sip> parameters, $uri->params_form and $uri->params.
+
+=item B<sips>:
+
+See I<sip> scheme.  Its syntax is the same as sip, but the default
+port is different.
+
 =item B<snews>:
 
-See I<news> scheme.  It's syntax is the same as news, but the default
+See I<news> scheme.  Its syntax is the same as news, but the default
 port is different.
 
 =item B<telnet>:
@@ -732,12 +756,50 @@ An old speficication of the I<telnet> URI scheme is found in RFC
 1738. C<URI> objects belonging to the telnet scheme support the
 common, generic and server methods.
 
-=back
+=item B<ssh>:
 
+Information about ssh is available at http://www.openssh.com/.
+C<URI> objects belonging to the ssh scheme support the common,
+generic and server methods. In addition they provide methods to
+access the userinfo sub-components: $uri->user and $uri->password.
+
+=item B<urn>:
+
+The syntax of Uniform Resource Names is specified in RFC 2141.  C<URI>
+objects belonging to the urn scheme provide the common methods and the
+methods: $uri->nid and $uri->nss that returns the Namespace Identifier
+and the Namespace Specific String respectively.
+
+The Namespace Identifier basically works like the Scheme identifier of
+URIs, and further divides the URN namespace.  Namespace Identifier
+assignments are maintained at
+<http://www.iana.org/assignments/urn-namespaces>.
+
+Letter case is not significant for the Namespace Identifier.  It is
+always returned in lower case by the $uri->nid method.  The $uri->_nid
+method can be used if you want it in its original case.
+
+=item B<urn>:B<isbn>:
+
+The C<urn:isbn:> namespace contains International Standard Book
+Numbers (ISBNs) and is described in RFC 3187.  C<URI> object belonging
+to this namespace has the following extra methods (if the
+Business::ISBN module is available); $uri->isbn,
+$uri->isbn_publisher_code, $uri->isbn_country_code, $uri->isbn_as_ean.
+
+=item B<urn>:B<oid>:
+
+The C<urn:oid:> namespace contains Object Identifiers (OIDs) and is
+described in RFC 3061.  An object identifier is sequences of digits
+separated by dots.  C<URI> object belonging to this namespace has an
+additional method called $uri->oid that can be used to get/set the oid
+value.  In list context oid numbers are returned as separate elements.
+
+=back
 
 =head1 CONFIGURATION VARIABLES
 
-The following configuration variables influence how the class and it's
+The following configuration variables influence how the class and its
 methods behave:
 
 =over 4
@@ -768,7 +830,7 @@ examples:
   URI->new("../../../foo")->abs("http://host/a/b")
       ==> "http://host/../../foo"
 
-  local $URI::URL::ABS_REMOTE_LEADING_DOTS = 1;
+  local $URI::ABS_REMOTE_LEADING_DOTS = 1;
   URI->new("../../../foo")->abs("http://host/a/b")
       ==> "http://host/foo"
 
@@ -784,6 +846,14 @@ them. E.g.:
    /(...)/ || die;
    $u->query("$1");
 
+=head1 PARSING URIs WITH REGEXP
+
+As an alternative to this module, the following (official) regular
+expression can be used to decode a URI:
+
+  my($scheme, $authority, $path, $query, $fragment) =
+  $uri =~ m|^(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*)(?:\?([^#]*))?(?:#(.*))?|;
+
 =head1 SEE ALSO
 
 L<URI::file>, L<URI::WithBase>, L<URI::Escape>, L<URI::Heuristic>
@@ -791,9 +861,15 @@ L<URI::file>, L<URI::WithBase>, L<URI::Escape>, L<URI::Heuristic>
 RFC 2396: "Uniform Resource Identifiers (URI): Generic Syntax",
 Berners-Lee, Fielding, Masinter, August 1998.
 
+http://www.iana.org/assignments/uri-schemes
+
+http://www.iana.org/assignments/urn-namespaces
+
+http://www.w3.org/Addressing/
+
 =head1 COPYRIGHT
 
-Copyright 1995-2001 Gisle Aas.
+Copyright 1995-2002 Gisle Aas.
 
 Copyright 1995 Martijn Koster.
 
